@@ -1,8 +1,6 @@
-header <- function(
-  name,
-  values,
-  sep = NULL
-) {
+header <- function(name,
+                   values,
+                   sep = NULL) {
   structure(
     list(
       name = name,
@@ -23,32 +21,25 @@ header <- function(
 #' @export
 #'
 #' @return A formatted header field.
-as.character.header <- function(x, width = 28, ...) {
-  FORMAT <- glue("%-{width}s %s")
-  INDENT <- strrep(" ", width + 1)
+as.character.header <- function(x, width = 30, ...) {
+  FORMAT <- glue("%-{width}s")
+  INDENT <- strrep(" ", width)
 
-  header <- sprintf(
-    FORMAT,
-    paste0(x$name, ":"),
+  paste0(
+    sprintf(
+      FORMAT,
+      paste0(x$name, ":")
+    ),
     paste(
-      sapply(x$values, as.character),
-      collapse = x$sep
+      as.character(x$values, ...),
+      collapse = paste0(x$sep, CRLF, INDENT)
     )
   )
-
-  # Split header parameters across lines.
-  if (!is.null(x$sep)) {
-    header <- header %>%
-      str_replace_all(
-        paste0("(", str_trim(x$sep, side = "right"), ")"),
-        paste0("\\1", CRLF, INDENT)
-      )
-  }
-
-  header
 }
+# as.character.header(msg$headers$To) %>% cat()
 
-print.header <- function(x, ... ) {
+#' @export
+print.header <- function(x, ...) {
   print(as.character(x))
 }
 
@@ -59,10 +50,11 @@ header_get <- function(msg, name) {
 header_set <- function(msg, name, values, append = FALSE, sep = NULL) {
   # Get current header.
   header <- msg$headers[[name]]
-  # Header has not previously been set.
   if (is.null(header)) {
+    # Header has not previously been set.
     header <- header(name, c(), sep)
   } else {
+    # Header has previously been set.
     if (append) {
       values <- c(header$values, values)
     }
